@@ -45,8 +45,8 @@ static gchar *DefaultHeight = "Dialog|GtkWindow::default_height";
 static gchar *Shrink = "Dialog|GtkWindow::allow_shrink";
 static gchar *Grow = "Dialog|GtkWindow::allow_grow";
 static gchar *AutoShrink = "Dialog|GtkWindow::auto_shrink";
-static gchar *WMName = "Dialog|GtkWindow::wmclass_name";
-static gchar *WMClass = "Dialog|GtkWindow::wmclass_class";
+static gchar *IconName = "Dialog|GtkWindow::icon_name";
+static gchar *FocusOnMap = "Dialog|GtkWindow::focus_on_map";
 
 static gchar *Resizable = "Dialog|GtkWindow::resizable";
 static gchar *DestroyWithParent = "Dialog|GtkWindow::destroy_with_parent";
@@ -61,6 +61,7 @@ static gchar *Gravity = "Dialog|GtkWindow::gravity";
 
 static gchar *HasSeparator = "GtkDialog::has_separator";
 
+static gchar *Urgency = "Dialog|GtkWindow::urgency_hint";
 
 static void show_dialog_creation_dialog (GbWidgetNewData * data);
 
@@ -204,10 +205,10 @@ on_dialog_ok (GtkWidget * widget, GbWidgetNewData * data)
 	}
       else if (GTK_TOGGLE_BUTTON (cancel_apply_ok)->active)
 	{
-	  add_button (dialog, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-		      "cancelbutton");
 	  add_button (dialog, GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
 		      "applybutton");
+	  add_button (dialog, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		      "cancelbutton");
 	  add_button (dialog, GTK_STOCK_OK, GTK_RESPONSE_OK,
 		      "okbutton");
 	}
@@ -390,10 +391,10 @@ gb_dialog_create_properties (GtkWidget * widget, GbWidgetCreateArgData * data)
 					Title, Type, Position, Modal,
 					DefaultWidth, DefaultHeight,
 					Shrink, Grow, AutoShrink,
-					WMName, WMClass,
+					IconName, FocusOnMap,
 					Resizable, DestroyWithParent, Icon,
 					Role, TypeHint, SkipTaskbar,
-					SkipPager, Decorated, Gravity);
+					SkipPager, Decorated, Gravity, Urgency);
   property_add_bool (HasSeparator, _("Has Separator:"),
 		     _("If the dialog has a horizontal separator above the buttons"));
 }
@@ -411,10 +412,10 @@ gb_dialog_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
 				     Title, Type, Position, Modal,
 				     DefaultWidth, DefaultHeight,
 				     Shrink, Grow, AutoShrink,
-				     WMName, WMClass,
+				     IconName, FocusOnMap,
 				     Resizable, DestroyWithParent, Icon,
 				     Role, TypeHint, SkipTaskbar,
-				     SkipPager, Decorated, Gravity);
+				     SkipPager, Decorated, Gravity, Urgency);
   gb_widget_output_bool (data, HasSeparator,
 			 gtk_dialog_get_has_separator (GTK_DIALOG (widget)));
 }
@@ -434,10 +435,10 @@ gb_dialog_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 				     Title, Type, Position, Modal,
 				     DefaultWidth, DefaultHeight,
 				     Shrink, Grow, AutoShrink,
-				     WMName, WMClass,
+				     IconName, FocusOnMap,
 				     Resizable, DestroyWithParent, Icon,
 				     Role, TypeHint, SkipTaskbar,
-				     SkipPager, Decorated, Gravity);
+				     SkipPager, Decorated, Gravity, Urgency);
   has_separator = gb_widget_input_bool (data, HasSeparator);
   if (data->apply)
     {
@@ -483,10 +484,10 @@ gb_dialog_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 				   Title, Type, Position, Modal,
 				   DefaultWidth, DefaultHeight,
 				   Shrink, Grow, AutoShrink,
-				   WMName, WMClass,
+				   IconName, FocusOnMap,
 				   Resizable, DestroyWithParent, Icon,
 				   Role, TypeHint, SkipTaskbar,
-				   SkipPager, Decorated, Gravity);
+				   SkipPager, Decorated, Gravity, Urgency);
 
   if (!gtk_dialog_get_has_separator (GTK_DIALOG (widget)))
     {
