@@ -121,7 +121,7 @@ struct _GladeMenuEditorClass
 };
 
 
-guint      glade_menu_editor_get_type    (void);
+GType      glade_menu_editor_get_type    (void);
 
 /* This creates a menu editor to edit the given menubar or popup menu in
    the given project. When the user selects the 'OK' or 'Apply' buttons,
